pub struct Audio {
pub channel: Sender<AudioCommand>,
}Expand description
Holds the command channel
Fields
channel: Sender<AudioCommand>Tokio mpsc sender used to communicate with the audio thread
Implementations
Sourceimpl Audio
impl Audio
Sourcepub fn new() -> Audio
pub fn new() -> Audio
Creates a new Audio instance and spawns the background audio thread
Workflow:
- Opens a default
rodiooutput stream. - Listens on an mpsc channel for
AudioCommands. - On
Play, stops any existing sink and starts a new one.
Sourcepub async fn play_audio(
&mut self,
path: &Path,
_interrupt_current_playback: bool,
) -> Result<()>
pub async fn play_audio( &mut self, path: &Path, _interrupt_current_playback: bool, ) -> Result<()>
Sends a Play command for the given path
Examples found in repository?
examples/hello.rs (line 45)
29 fn key_down_event(
30 &self,
31 game: &mut Game,
32 _timestamp: u64,
33 _window_id: u32,
34 keycode: Option<sdl3::keyboard::Keycode>,
35 _scancode: Option<sdl3::keyboard::Scancode>,
36 _keymod: sdl3::keyboard::Mod,
37 _repeat: bool,
38 _which: u32,
39 _raw: u16,
40 ) -> anyhow::Result<()> {
41 println!("{:?}", keycode);
42 tokio::task::block_in_place(move || {
43 Handle::current().block_on(async move {
44 game.audio
45 .play_audio(Path::new("examples/music.ogg"), false)
46 .await
47 .unwrap();
48 })
49 });
50 Ok(())
51 }Trait Implementations