pub struct Image {
pub path: PathBuf,
pub buffer: Rc<RefCell<Vec<u8>>>,
pub texture: Rc<Texture<'static>>,
pub width: u32,
pub height: u32,
}Expand description
Simple image asset that stores its file location.
Fields
path: PathBufFilesystem path to the image.
buffer: Rc<RefCell<Vec<u8>>>texture: Rc<Texture<'static>>width: u32height: u32Trait Implementations
Sourceimpl LoadableResource for Image
impl LoadableResource for Image
Sourcefn load(
path: PathBuf,
texture_creator: &Arc<TextureCreator<WindowContext>>,
) -> Result<Box<dyn LoadableResource>>
fn load( path: PathBuf, texture_creator: &Arc<TextureCreator<WindowContext>>, ) -> Result<Box<dyn LoadableResource>>
Construct an Image from path and return it as a boxed trait object.
Errors
This implementation never fails, but the signature matches the trait.
Sourcefn name(&self) -> String
fn name(&self) -> String
Identifier for the asset is the the string representation of its path.
Sourcefn as_mut_slice(&self) -> &mut [u8] ⓘ
fn as_mut_slice(&self) -> &mut [u8] ⓘ
Return a mutable slice that the graphics thread can pass to SDL