pub struct ResourceManager {
pub resources: HashMap<String, Box<dyn LoadableResource>>,
}Expand description
Manages a collection of loadable resources indexed by their name
Fields
resources: HashMap<String, Box<dyn LoadableResource>>Map resource name to a type that implements LoadableResource trait
Implementations
Sourceimpl ResourceManager
impl ResourceManager
Sourcepub fn cache_asset(&mut self, asset: Box<dyn LoadableResource>) -> Result<()>
pub fn cache_asset(&mut self, asset: Box<dyn LoadableResource>) -> Result<()>
Insert a loaded asset into the cache
The asset is stored under the key returned by asset.name()
pub fn get_asset(&mut self, name: String) -> Result<&Box<dyn LoadableResource>>
pub fn is_cached(&mut self, name: String) -> bool