LoadableResource

Trait LoadableResource 

pub trait LoadableResource: Any {
    // Required methods
    fn load(
        path: PathBuf,
        graphics: &mut Graphics,
        size: Option<f32>,
    ) -> Result<Box<dyn LoadableResource>>
       where Self: Sized;
    fn name(&self) -> String;

    // Provided methods
    fn as_mut_slice(&self) -> Option<&mut [u8]> { ... }
    fn as_slice(&self) -> Option<Ref<'_, [u8]>> { ... }
}
Trait that all loadable assets must implement

Required Methods

fn load( path: PathBuf, graphics: &mut Graphics, size: Option<f32>, ) -> Result<Box<dyn LoadableResource>>
where Self: Sized,

Load a resource from path and return it boxed

Arguments

path: path to the resoruce file graphics: current Graphics instance which holds texture_creator and ttf_context size: optional size for any resoruce that needs it

Errors

Returns an error if the file cannot be read or parsed

fn name(&self) -> String

Eaasy-to-use identifier for the resource

Provided Methods

fn as_mut_slice(&self) -> Option<&mut [u8]>

Return a mutable slice that the graphics thread can pass to SDL

If the resource does not have a buffer, then it mustn’t implement this function

fn as_slice(&self) -> Option<Ref<'_, [u8]>>

Return an immutable slice for read‑only access

If the resource does not have a buffer, then it mustn’t implement this function

Implementors