pub struct Game {
pub name: String,
pub author: String,
pub graphics: Graphics,
pub audio: Audio,
pub resource_manager: Arc<Mutex<ResourceManager>>,
}Expand description
Main game struct
Holds basic metadata and a reference to the graphics subsystem.
User must create a Game in order to feed it to the EventHandler
Fields
name: StringHuman-readable game title.
Author or owner of the game.
graphics: GraphicsGraphics subsystem used to render frames.
audio: AudioAudio subsystem
resource_manager: Arc<Mutex<ResourceManager>>Resource management
Implementations
Sourceimpl Game
impl Game
Sourcepub fn new(
name: String,
author: String,
graphics: Graphics,
resource_manager: Arc<Mutex<ResourceManager>>,
) -> Game
pub fn new( name: String, author: String, graphics: Graphics, resource_manager: Arc<Mutex<ResourceManager>>, ) -> Game
Create a new Game instance.
Parameters
name: title of the gameauthor: author/owner namegraphics: initialized graphics subsystem
Returns
A Game instance ready to be used by an EventHandler.
Examples found in repository?
examples/hello.rs (lines 75-80)
68async fn main() {
69 let resource_manager = Arc::new(Mutex::new(ResourceManager::new()));
70 let graphics = graphics::Graphics::new(
71 String::from("my cool game"),
72 (500, 500),
73 resource_manager.clone(),
74 );
75 let mut game = fennel_engine::Game::new(
76 String::from("my cool game"),
77 String::from("wiltshire"),
78 graphics.unwrap(),
79 resource_manager,
80 );
81 events::run(&mut game, Box::new(State {})).await;
82}Trait Implementations