Graphics

Struct Graphics 

pub struct Graphics {
    pub canvas: Canvas<Window>,
    pub sdl_context: Sdl,
    pub texture_creator: TextureCreator<WindowContext>,
}
Owned SDL variables used for rendering

  • canvas: the drawing surface for the window
  • sdl_context: the SDL context

Fields

canvas: Canvas<Window>

The SDL3 canvas, required to draw

sdl_context: Sdl

SDL3 contaxt

texture_creator: TextureCreator<WindowContext>

SDL3 texture creator

Implementations

Source

impl Graphics

pub fn new( name: String, dimensions: (u32, u32), ) -> Result<Graphics, Box<dyn Error>>

Initialize SDL3, create a centered, resizable window and return a Graphics container with the canvas and SDL context.

Parameters
  • name: Window title.
  • dimensions: (width, height) in pixels (u32).
Returns
  • Ok(Graphics) on success.
  • Err(Box<dyn std::error::Error>) on failure (window/canvas build error).
Example
let graphics = graphics::new(String::from("my cool game"), (500, 500))?;
Examples found in repository?
examples/hello.rs (line 56)
55async fn main() {
56    let graphics = graphics::Graphics::new(String::from("my cool game"), (500, 500));
57    let mut game = fennel_engine::Game::new(
58        String::from("my cool game"),
59        String::from("wiltshire"),
60        graphics.unwrap(),
61    );
62    events::run(&mut game, Box::new(State {})).await;
63}
pub fn draw_image( &mut self, path: String, position: (f32, f32), manager: &mut ResourceManager, ) -> Result<()>

Cache an image if it isn’t cached and draw it on the canvas

Parameters
  • path: Path to the image
  • position: Where to draw the image in the window (x,y) in pixels (f32).
Returns
  • Ok(()) on success.
  • Err(Box<dyn std::error::Error>) on failure
Example
graphics.draw_image(String::from("examples/example.png"), (0.0, 0.0));
Examples found in repository?
examples/hello.rs (lines 19-23)
15    async fn draw(&self, game: &mut Game) -> anyhow::Result<()> {
16        game.graphics.canvas.set_draw_color(Color::RGB(0, 0, 0));
17        game.graphics.canvas.clear();
18        game.graphics
19            .draw_image(
20                "examples/example.png".to_string(),
21                (0.0, 0.0),
22                &mut game.resource_manager,
23            )
24            .expect("failed to draw an image");
25        game.graphics.canvas.present();
26        Ok(())
27    }