ComponentFactory

Trait ComponentFactory 

pub trait ComponentFactory: Send + Sync {
    // Required method
    fn insert(&self, world: &mut World, entity: Entity, value: &Value);
}
All components must have a factory implementing this trait to be able created from a scene config

Required Methods

fn insert(&self, world: &mut World, entity: Entity, value: &Value)

Implementors