Game

Struct Game 

pub struct Game {
    pub name: String,
    pub author: String,
    pub graphics: Graphics,
    pub audio: Audio,
    pub resource_manager: ResourceManager,
}
Main game struct

Holds basic metadata and a reference to the graphics subsystem. User must create a Game in order to feed it to the EventHandler

Fields

name: String

Human-readable game title.

author: String

Author or owner of the game.

graphics: Graphics

Graphics subsystem used to render frames.

audio: Audio

Audio subsystem

resource_manager: ResourceManager

Resource management

Implementations

Source

impl Game

pub fn new(name: String, author: String, graphics: Graphics) -> Game

Create a new Game instance.

Parameters
  • name: title of the game
  • author: author/owner name
  • graphics: initialized graphics subsystem
Returns

A Game instance ready to be used by an EventHandler.

Examples found in repository?
examples/hello.rs (lines 57-61)
55async fn main() {
56    let graphics = graphics::Graphics::new(String::from("my cool game"), (500, 500));
57    let mut game = fennel_engine::Game::new(
58        String::from("my cool game"),
59        String::from("wiltshire"),
60        graphics.unwrap(),
61    );
62    events::run(&mut game, Box::new(State {})).await;
63}