pub struct Game {
pub name: String,
pub author: String,
pub graphics: Graphics,
pub audio: Audio,
pub resource_manager: ResourceManager,
}Expand description
Main game struct
Holds basic metadata and a reference to the graphics subsystem.
User must create a Game in order to feed it to the EventHandler
Fields
name: StringHuman-readable game title.
Author or owner of the game.
graphics: GraphicsGraphics subsystem used to render frames.
audio: AudioAudio subsystem
resource_manager: ResourceManagerResource management
Implementations